diff -ruN nagiosplug-save/contrib/check_rrd_data.pl nagiosplug/contrib/check_rrd_data.pl
--- nagiosplug-save/contrib/check_rrd_data.pl	2002-02-28 06:42:54.000000000 +0000
+++ nagiosplug/contrib/check_rrd_data.pl	2004-03-27 23:05:16.000000000 +0000
@@ -35,38 +35,61 @@
 # Copyright Notice: GPL
 #
 
-# Doesn't work! Why?
-# BEGIN {
-        # my $runtimedir = substr($0,0,rindex($0,'/'));
-        # require "$runtimedir/utils.pm";
-# }
+require 5.004;
+use strict;
+use lib utils.pm ;
+use Plugin;
+use Plugin::Parameter qw(:DEFAULT);
+
+use vars qw($PROGNAME $opt_D $opt_t $opt_ds $opt_f $opt_w $opt_c $opt_d);
+
+use utils qw(%ERRORS);
 
-require '/usr/libexec/nagios/plugins/utils.pm';
 use RRD::File;
-# use strict;			# RRD:File and utils.pm don't like this
 
-my $configfilepath = "/var/spool/nagios/rrd-files";	# Change if needed
+my $f_opt = new Plugin::Parameter(-name => "rrdfile", -flags => [ 'f', 'rrdfile' ],
+				  -optional => "no", -valueoptional => "no", -type => "FILENAME",
+				  -description => "RRD File name or machine_id");
+my $w_opt = new Plugin::Parameter(-name => "warning", -flags => [ 'w', 'warning' ],
+				  -optional => "no", -valueoptional => "no", -type => "PERLEXP",
+				  -description => "Perl expression applied to current value of the data source - positive result gives warning");
+my $c_opt = new Plugin::Parameter(-name => "critical", -flags => [ 'c', 'critical' ],
+				  -optional => "no", -valueoptional => "no", -type => "PERLEXP",
+				  -description => "Perl expression applied to current value of the data source - positive result gives critical");
+my $d_opt = new Plugin::Parameter(-name => "default", -flags => [ 'd', 'default' ],
+				  -optional => "yes", -valueoptional => "no", -type => "PERLEXP",
+				  -default => sub { return ""; },
+				  -description => "Perl expression evaluated if no warning or critical state detected");
+my $ds_opt = new Plugin::Parameter(-name => "dataset", -flags => [ 'ds', 'dataset' ],
+				   -optional => "yes", -valueoptional => "no", -type => "INTEGER",
+				   -default => 0,
+				   -description => "Which RRD dataset do we want to check");
+my $D_opt = new Plugin::Parameter(-name => "directory", -flags => [ 'D', 'directory' ],
+				  -optional => "yes", -valueoptional => "no", -type => "DIRECTORY",
+				  -default => "/var/spool/nagios/rrd-files",
+				  -description => "Path to RRD-Files for machinid matching");
+my $plugin = new Plugin(-revision => '$Revision: 1.1.1.1 $',
+			-copyright => "2000 Esteban Manchado Velzquez, 2004 Howard Wilkinson <howard\@cohtech.com>",
+			-shortcomment => "Checks data from a RRD file. machine_id is normally an IP address, that has to be mapped to a RRD file, by means of the config file (by default /var/spool/nagios/rrd-files, a file with pairs of (machine_id,rrd_file), separated by whitespace). It can be a RRD file, too.",
+			-parameterlists => [ [ $f_opt, $w_opt, $c_opt, $d_opt, $ds_opt, $D_opt, $t_opt ], $h_opts, $V_opts ]);
+
+
+$plugin->init();
+
+my $configfilepath = $opt_D;
+
 my %hostfile;						# For storing config
 my $rrdfile;						# RRD file to open
 
 $ENV{'PATH'} = "/bin:/usr/bin";
 $ENV{'ENV'} = "";
 
-if (scalar @ARGV != 4 && scalar @ARGV != 5) {
-	print STDERR join "' '", @ARGV, "\n";
-	my $foo = 'check_rrd_data';
-	print STDERR $foo, " <file.rrd> <perl_exp_warn> <perl_exp_crit> <perl_exp_default> [<ds>]\n\n";
-	print STDERR "<perl_exp_*> is an expression that gets evaluated with \$_ at the current\n";
-	print STDERR "value of the data source. If it returns something other than \"\", there\n";
-	print STDERR "will be a warning or a critical failure. Else, the expression\n";
-	print STDERR "<perl_exp_default> will be evaluated\n";
-	exit;
-}
+$plugin->start_timeout($opt_t, "HUNG while reading files");
 
 # Check configuration file
 open F, $configfilepath or do {
-	print "Can't open config file $configfilepath\n";
-	return $ERRORS{'UNKNOWN'};
+        $plugin->usage();
+	utils::usage("$PROGNAME UNKNOWN: Can't open config file $configfilepath\n");
 };
 while (<F>) {
 	next unless /(.+)\s+(.+)/;
@@ -75,44 +98,42 @@
 close F;
 
 # Default
-my $ds = defined $ARGV[4]?$ARGV[4]:0;
-	# print "\$ds = " . $ds . ":";
-	# print "\$ARGV[4] = " . $ARGV[4] . ":";
+my $ds = $opt_ds;
 $ds =~ s/\$//g;		# Sometimes Nagios gives 1$ as the last parameter
 
 # Guess which RRD file have to be opened
-$rrdfile = $ARGV[0] if (-r $ARGV[0]);		# First the parameter
-$rrdfile = $hostfile{$ARGV[0]} unless $rrdfile;	# Second, the config file
-	# print "$ARGV[0]:";
+$rrdfile = $opt_f if (-r $opt_f);		# First the parameter
+$rrdfile = $hostfile{$opt_f} unless $rrdfile;	# Second, the config file
 
 if (! $rrdfile) {
-	print "Can't open data file for $ARGV[0]\n";	# Aaaargh!
-	return $ERRORS{'UNKNOWN'};	# Unknown
+        $plugin->usage();
+	utils::usage("$PROGNAME UNKNOWN: Can't open data file for $opt_f\n");
 }
 
-	# print "Opening file $rrdfile:";
 my $rrd = new RRD::File ( -file => $rrdfile );
 $rrd->open();
 if (! $rrd->loadHeader()) {
-	print "Couldn't read header from $rrdfile\n";
-	exit $ERRORS{'UNKNOWN'};	# Unknown
+        $plugin->usage();
+	utils::usage("$PROGNAME UNKNOWN: Couldn't read header from $rrdfile\n");
 }
 my $value = $rrd->getDSCurrentValue($ds);
 $rrd->close();
 
 # Perl expressions to evaluate
 my ($perl_exp_warn, $perl_exp_crit, $perl_exp_default) =
-		($ARGV[1], $ARGV[2], $ARGV[3]);
+		($opt_w, $opt_c, $opt_d);
 my $result;	# Result of the expressions (will be printed)
 my @data;	# Special data reserved for the expressions, to pass data
 
+# We should force Nagios style output here but for backwards compatibility
+# Allow anything!
 # First check for critical errors
 $perl_exp_crit =~ /(.*)/;
 $perl_exp_crit = $1;
 $result = eval $perl_exp_crit;
 if ($result) {
 	print $result;
-	exit 2;		# Critical
+	exit $ERRORS{'CRITICAL'};		# Critical
 }
 
 # Check for warnings
@@ -121,9 +142,12 @@
 $result = eval $perl_exp_warn;
 if ($result) {
 	print $result;
-	exit 1;		# Warning
+	exit $ERRORS{'WARNING'};		# Warning
 }
 
 $perl_exp_default =~ /(.*)/;
 $perl_exp_default = $1;
-eval $perl_exp_default;	# Normally returns 0 (OK)
+$result = eval $perl_exp_default;
+print $result;
+exit $ERRORS{'OK'};
+
